#!/bin/bash
# Name: Steffen Wirth
# Homepage: http://www.pissflitsche.net/kernelscript
# Version: 0.3.8
# Datum: 07.01.2006
version=0.3.8
clear
if [ `id -un` != root ] 
	then 
		dialog --title "root access requirement" --backtitle "kernelscript $version" --msgbox "       Please start the script as root" 5 50
		exit 0
fi


function start {
	echo "Please wait a few seconds. Check kernel versions..."
	rm -rf ~/.kernelscript/ 2> /dev/null
	mkdir ~/.kernelscript/ 2> /dev/null
	touch ~/.kernelscript/vpatch && touch ~/.kernelscript/vkernel
	cd ~/.kernelscript/ && wget http://www.kernel.org/kdist/finger_banner 2> /dev/null
	cat finger_banner | grep "The latest stable version of the Linux kernel is" | cut -b 61-68 > stable26
	cat finger_banner | grep "The latest snapshot for the stable Linux kernel tree is: " | cut -b 61-75 > stable26test
	cat finger_banner | grep "The latest 2.4 version of the Linux kernel is:" | cut -b 61-66 > stable24
	cat finger_banner | grep "The latest -ac patch to the stable Linux kernels is: " | cut -b 61-70 > acpatch
	cat finger_banner | grep "The latest -mm patch to the stable Linux kernels is:" | cut -b 61-74 > mmpatch
	unset stable26 stable26test stable24 acpatch mmpatch
	stable26=`cat stable26`
	stable26test=`cat stable26test`
	stable24=`cat stable24`
	acpatch=`cat acpatch`
	mmpatch=`cat mmpatch`
	clear
	dialog --backtitle "kernelscript $version" --checklist "Please choose one kernel:" 0 0 0 "$stable26" "The latest 2.6 version" On "$stable26test" "The latest testing 2.6 version" Off "$stable24" "The latest 2.4 version" Off 2> ~/.kernelscript/vkernel
	dialog --title "Patchset" --backtitle "kernelscript $version" --yesno "Do you want install some patches (ac, mm)?\nAfter downloading kernel you can choose..." 6 50
	if [ $? == 0 ]; then
		PATCH=1
	else
		echo "No Patch"
	fi
}

function patchkernel {
	if [ $PATCH == 1 ]; then
	dialog --backtitle "kernelscript $version" --checklist "Please choose a patch:" 0 0 0 "$mmpatch" "-mm patch set" On "$acpatch" "-ac patch set" Off 2> ~/.kernelscript/vpatch
		if [ `cat ~/.kernelscript/vpatch` == "\"$acpatch\"" ] ; then
			cd /usr/src/ && wget http://kernel.org/pub/linux/kernel/people/alan/linux-2.6/2.6.11/patch-$acpatch.bz2
			bunzip2 patch-$acpatch.bz2
			patch -p0 < patch-$acpatch
			PATCH=0
		else
			cd /usr/src && wget http://kernel.org/pub/linux/kernel/people/akpm/patches/2.6/$stable26/$mmpatch/$mmpatch.bz2
			bunzip2 $mmpatch.bz2
			patch -p0 < $mmpatch
			PATCH=0

		fi
			
			
			
	else
		echo ""
	fi
}

function stable {
	mkdir /usr/src 2> /dev/null
	rm /usr/src/linux-$stable26.tar.gz & 2> /dev/null
	rm -rf /usr/src/linux-$stable26/ & 2> /dev/null
	cd /usr/src/ && wget ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-$stable26.tar.gz || wget -c ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-$stable26.tar.gz
	clear
	echo "Kernel becomes now unpacked!"
	tar -xvzf linux-$stable26.tar.gz && rm ./linux
	ln -s /usr/src/linux-$stable26 /usr/src/linux
	patchkernel
	cd /usr/src/linux/ && make menuconfig
	make all && make modules_install || echo "compile error"
	cp ./System.map /boot/System.map-$stable26  || exit 1
	cp ./arch/i386/boot/bzImage /boot/vmlinuz-$stable26 &
	mkinitrd /boot/initrd-$stable26 $stable26 || mkinitrd || mk_initrd
	clear
	dialog --title "Kernel ready to boot" --backtitle "kernelscript $version" --msgbox "Kernel: /boot/vmlinuz-$stable26\nSystem: /boot/System.map-$stable26\nNow you must only insert the new kernel in your bootloader" 7 65
	exit 0
}


function ktest {
	mkdir /usr/src 2> /dev/null
	rm /usr/src/linux-$stable26test.tar.gz & 2> /dev/null
	rm -rf /usr/src/linux-$stable26test/ & 2> /dev/null
	cd /usr/src/ && wget ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-$stable26test.tar.gz || wget -c ftp://ftp.kernel.org/pub/linux/kernel/v2.6/linux-$stable26test.tar.gz
	clear
	echo "Kernel becomes now unpacked!"
	tar -xvzf linux-$stable26test.tar.gz && rm ./linux
	ln -s /usr/src/linux-$stable26test /usr/src/linux
	patchkernel
	cd /usr/src/linux/ && make menuconfig
	make all && make modules_install || echo "compile error"
	cp ./System.map /boot/System.map-$stable26test || exit 1
	cp ./arch/i386/boot/bzImage /boot/vmlinuz-$stable26test &
	mkinitrd /boot/initrd-$stable26test $stable26test || mkinitrd || mk_initrd
	clear
	dialog --title "Kernel ready to boot" --backtitle "kernelscript $version" --msgbox "Kernel: /boot/vmlinuz-$stable26test\nSystem: /boot/System.map-$stable26test\nNow you must only insert the new kernel in your bootloader" 7 65
	exit 0
}


function stablezwo {
	clear
	mkdir /usr/src 2> /dev/null
	rm /usr/src/linux-$stable24.tar.gz & 2> /dev/null
	rm -rf /usr/src/linux-$stable24/ & 2> /dev/null
	cd /usr/src/ && wget ftp://ftp.kernel.org/pub/linux/kernel/v2.4/linux-$stable24.tar.gz || wget -c ftp://ftp.kernel.org/pub/linux/kernel/v2.4/linux-$stable24.tar.gz
	clear
	echo "Kernel becomes now unpacked!"
	tar -xzf linux-$stable24.tar.gz && rm ./linux
	ln -s ./linux-$stable24 ./linux
	patchkernel
	cd /usr/src/linux/ && make menuconfig
	make dep clean bzImage || echo "kernel compile error"
	make modules || echo "module compile error"
	make modules_install || echo "modules_install error"
	rm -rf /boot/System.map-$stable24 & 2> /dev/null
	rm -rf /boot/vmlinuz-$stable24 & 2> /dev/null
	cp ./System.map /boot/System.map-$stable24 || exit 1
	cp ./arch/i386/boot/bzImage /boot/vmlinuz-$stable24 &
	mkinitrd /boot/initrd-$stable24 $stable24 || mkinitrd || mk_initrd
	clear
	dialog --title "Kernel ready to boot" --backtitle "kernelscript $version" --msgbox "Kernel: /boot/vmlinuz-$stable24\nSystem: /boot/System.map-$stable24\nNow you must only insert the new kernel in your bootloader" 7 65
	exit 0
}



#letz start
start
if [ `cat ~/.kernelscript/vkernel` == "\"$stable26\"" ] ; then
	stable
else
	if [ `cat ~/.kernelscript/vkernel` == "\"$stable26test\"" ] ; then
		ktest
	else
		stablezwo
	fi
fi
exit 0




#if [ `cat ~/.kernelscript/vkernel` == "\"$stable26\"" ] ; then
